<?php
/**
 * Portfolio Customizer options
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */

// Add portfolio enable section
$wp_customize->add_section( 'photo_fusion_pro_portfolio_section', array(
	'title'             => esc_html__( 'Portfolio','photo-fusion-pro' ),
	'panel'             => 'photo_fusion_pro_sections_panel'
) );

// Add portfolio enable setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[portfolio_enable]', array(
	'default'           => $options['portfolio_enable'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[portfolio_enable]', array(
	'label'             => esc_html__( 'Enable on', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_portfolio_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_enable_disable_options()
) );

// Add photo gallery source
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[portfolio_source]', array(
	'default'           => $options['portfolio_source'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[portfolio_source]', array(
	'label'             => esc_html__( 'Photo Gallery Source', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_portfolio_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_portfolio_source(),
	'active_callback' => 'photo_fusion_pro_is_portfolio_active', 
) );

// Add portfolio title setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[portfolio_title]', array(
	'default'           => $options['portfolio_title'],
	'sanitize_callback' => 'sanitize_text_field',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[portfolio_title]', array(
	'label'           => esc_html__( 'Title', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_portfolio_section',
	'type'            => 'text',
	'active_callback' => 'photo_fusion_pro_portfolio_source_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'photo_fusion_pro_theme_options[portfolio_title]', array(
		'selector'            => '#portfolio h2.entry-title',
		'render_callback'     => 'photo_fusion_pro_customize_partial_portfolio_title',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// Add portfolio title setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[portfolio_description]', array(
	'default'           => $options['portfolio_description'],
	'sanitize_callback' => 'esc_textarea',
	'transport'         => 'postMessage',
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[portfolio_description]', array(
	'label'           => esc_html__( 'Short Description', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_portfolio_section',
	'type'            => 'textarea',
	'active_callback' => 'photo_fusion_pro_portfolio_source_active',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'photo_fusion_pro_theme_options[portfolio_description]', array(
		'selector'            => '#portfolio span.sub-title',
		'render_callback'     => 'photo_fusion_pro_customize_partial_portfolio_description',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
	) );
}

// no of images in portfolio.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[portfolio_no_of_img]', array(
	'default'           => $options['portfolio_no_of_img'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_number_range',
	'validate_callback' => 'photo_fusion_pro_validate_no_of_portfolio'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[portfolio_no_of_img]', array(
	'label'             => esc_html__( 'No of Images', 'photo-fusion-pro' ),
	'description'       => esc_html__( 'Notice: Please refresh after the number of image is set to see the effects.', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_portfolio_section',
	'type'              => 'number',
	'input_attrs'		=> array(
		'min'          	=> 1,
		'max' 			=> 16,
		'style'        	=> 'width: 80px;'
	),
	'active_callback' => 'photo_fusion_pro_portfolio_source_active', 
) );

// Add photo gallery post image layout.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[portfolio_image_layout]', array(
	'default'           => $options['portfolio_image_layout'],
	'sanitize_callback' => 'photo_fusion_pro_sanitize_select'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[portfolio_image_layout]', array(
	'label'             => esc_html__( 'Select Image Layout', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_portfolio_section',
	'type'              => 'select',
	'choices'           => photo_fusion_pro_photo_gallery_image_layout(),
	'active_callback' => 'photo_fusion_pro_portfolio_source_active', 
) );

// Add portfolio content type setting and control.
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[portfolio_content_type]', array(
	'sanitize_callback' => 'photo_fusion_pro_sanitize_category_list'
) );

$wp_customize->add_control( new photo_fusion_pro_Dropdown_Category_Control( $wp_customize, 'photo_fusion_pro_theme_options[portfolio_content_type]', array(
	'label'           => esc_html__( 'Select category', 'photo-fusion-pro' ),
	'section'         => 'photo_fusion_pro_portfolio_section',
	'type'            => 'dropdown-categories',
	'active_callback' => 'photo_fusion_pro_portfolio_source_active', 
) ) );

// page link
$wp_customize->add_setting( 'photo_fusion_pro_theme_options[portfolio_page_link]', array(
	'sanitize_callback' => 'absint'
) );

$wp_customize->add_control( 'photo_fusion_pro_theme_options[portfolio_page_link]', array(
	'label'             => esc_html__( 'Link Gallery Page', 'photo-fusion-pro' ),
	'section'           => 'photo_fusion_pro_portfolio_section',
	'type'              => 'dropdown-pages',
	'active_callback' => 'photo_fusion_pro_portfolio_source_active', 
) );
