<?php
/**
 * Photo Fusion Pro custom helper funtions
 *
 * This is the template that includes all the other files for core featured of Photo Fusion Pro
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */

if( ! function_exists( 'photo_fusion_pro_check_enable_status' ) ):
	/**
	 * Check status of content.
	 *
	 * @since Photo Fusion Pro 1.0
	 */
  	function photo_fusion_pro_check_enable_status( $input, $content_enable ){
		 $options = photo_fusion_pro_get_theme_options();

		 // Content status.
		 $content_status = $options[ $content_enable ];

		 // Get Page ID outside Loop.
		 $query_obj = get_queried_object();
		 $page_id   = null;
	    if ( is_object( $query_obj ) && 'WP_Post' == get_class( $query_obj ) ) {
	    	$page_id = get_queried_object_id();
	    }

		 // Front page displays in Reading Settings.
		 $page_on_front  = get_option( 'page_on_front' );

		 if ( ( ! is_home() && is_front_page() ) && ( 'static-frontpage' === $content_status ) || ( 'entire-site' === $content_status ) ) {
			$input = true;
		 }
		 else {
			$input = false;
		 }
		 return ( $input );

  	}
endif;
add_filter( 'photo_fusion_pro_section_status', 'photo_fusion_pro_check_enable_status', 10, 2 );


if ( ! function_exists( 'photo_fusion_pro_is_jetpack_cpt_module_enable' ) ) :
    /**
     * Check if JetPack module is enabled
     *
     * @since Photo Fusion Pro 1.0
     *
     * @param string $jetpack_cpt_option 		Jetpack enable checkbox value
     */
    function photo_fusion_pro_is_jetpack_cpt_module_enable( $jetpack_cpt_option ) {
		if ( class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'custom-content-types' ) &&  get_option( $jetpack_cpt_option ) ) :
			return true;
		endif;

		return false;
    }
endif;
add_action( 'plugins_loaded', 'photo_fusion_pro_is_jetpack_cpt_module_enable' );
add_filter( 'photo_fusion_pro_filter_is_jetpack_cpt_module_enable', 'photo_fusion_pro_is_jetpack_cpt_module_enable' );

if ( ! function_exists( 'photo_fusion_pro_is_sidebar_enable' ) ) :
	/**
	 * Check if sidebar is enabled in meta box first then in customizer
	 *
	 * @since Photo Fusion Pro 1.0
	 */
	function photo_fusion_pro_is_sidebar_enable() {
		$options               = photo_fusion_pro_get_theme_options();
		$sidebar_position      = $options['sidebar_position'];

		if ( is_home() ) {
			$post_id = get_option( 'page_for_posts' );
			if( ! empty( $post_id ) )
				$post_sidebar_position = get_post_meta( $post_id, 'photo-fusion-pro-sidebar-position', true );
			else
				$post_sidebar_position = '';
		} elseif( is_archive() || is_search() ) {
			$post_sidebar_position = '';
		} else {
			$post_sidebar_position = get_post_meta( get_the_id(), 'photo-fusion-pro-sidebar-position', true );
		}

		if ( ( $sidebar_position == 'no-sidebar' && $post_sidebar_position == "" ) || $post_sidebar_position == 'no-sidebar' ) {
			return false;
		} else {
			return true;
		}

	}
endif;


if ( ! function_exists( 'photo_fusion_pro_is_frontpage_content_enable' ) ) :
	/**
	 * Check home page ( static ) content status.
	 *
	 *.0
	 *
	 * @param bool $status Home page content status.
	 * @return bool Modified home page content status.
	 */
	function photo_fusion_pro_is_frontpage_content_enable( $status ) {
		if ( is_front_page() ) {
			$options = photo_fusion_pro_get_theme_options();
			$front_page_content_status = $options['enable_frontpage_content'];
			if ( false === $front_page_content_status ) {
				$status = false;
			}
		}
		return $status;
	}

endif;

add_filter( 'photo_fusion_pro_filter_frontpage_content_enable', 'photo_fusion_pro_is_frontpage_content_enable' );

if ( ! function_exists( 'photo_fusion_pro_portfolio_ajax_enqueuer' ) ) :
	/**
	 * ajax enquue
	 *
	 * @since Photo Fusion Pro 1.0.0
	 */
	function photo_fusion_pro_portfolio_ajax_enqueuer() {
	   	wp_register_script( "photo-fusion-pro-ajax", get_template_directory_uri() . '/assets/js/ajax.min.js', array( 'jquery' ), '', true );
	   	wp_localize_script( 'photo-fusion-pro-ajax', 'photo_fusion_pro', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ) ) );        
	   	wp_enqueue_script( 'photo-fusion-pro-ajax' );
	}
endif;
add_action( 'wp_enqueue_scripts', 'photo_fusion_pro_portfolio_ajax_enqueuer' );


if ( ! function_exists( 'photo_fusion_pro_gallery_ajax_handler' ) ) :
	/**
	 * ajax handler
	 *
	 * @since Photo Fusion Pro 1.0.0
	 */
	function photo_fusion_pro_gallery_ajax_handler(){
		$options = photo_fusion_pro_get_theme_options();

		// portfolio type
		$gallery_content_type    = $options['gallery_content_type'];
		$gallery_img_layout      = $options['gallery_image_layout'];
		$page = ( isset( $_POST['pageNumber'] ) ) ? absint( wp_unslash( $_POST['pageNumber'] ) ) : 2;
		$i = 1;
		$img_count = 1;
    	header("Content-Type: text/html");

		$args = array(
			'ignore_sticky_posts'=> true,
			'post_type'         => 'post',
			'posts_per_page'    => 8,
			'category__in'      => $gallery_content_type,
			'paged'    			=> $page,
		);

        $gallery_query = new WP_Query( $args );
            
        if ( $gallery_query->have_posts() ) :
				// The Loop
				while ( $gallery_query->have_posts() ) : $gallery_query->the_post();
					if ( has_post_thumbnail() ) {
						if ( $img_count == 9 ) :
							$img_count = 1;
						endif;
						if ( $gallery_img_layout == 'grid' ) {
							$tp_image_type = 'grid';
						} else {
							$tp_image_type = ( $img_count == 2 || $img_count == 4 || $img_count == 7 || $img_count == 8 ) ? 'grid' : 'condensed';
						}

						$img_array = wp_get_attachment_image_src( get_post_thumbnail_id(), 'photo-fusion-pro-portfolio-' . $tp_image_type );
						$img_array_large = wp_get_attachment_image_src( get_post_thumbnail_id(), 'large' );
					} else {
						if ( $gallery_img_layout == 'grid' ) {
	                        $tp_image_size = '300x300';
	                    } else {
	                        $tp_image_size = ( $img_count == 2 || $img_count == 4 || $img_count == 7 || $img_count == 8 ) ? '300x300' : '300x379';
	                    }
	                     $img_array[0]        = get_template_directory_uri().'/assets/uploads/no-featured-image-'.$tp_image_size.'.png';
	                     $img_array_large[0]  = get_template_directory_uri().'/assets/uploads/no-featured-image-'.$tp_image_size.'.png';
						}					
						
						$post_categories = get_the_category();
						
						if( ! empty( $img_array[0] ) ): 
						?>
							<div class="box item-w1 <?php echo ( $img_count == 2 || $img_count == 4 || $img_count == 7 || $img_count == 8 ) ? ' item-h2 ' : ' item-h1 ';
								foreach ( $post_categories as $post_category ) {
									$category_slug = $post_category->slug;
									echo esc_attr( $category_slug ) . ' ';
								} ?>">
							<figure>
								<a href="#">
									<img src="<?php echo esc_url( $img_array[0] ); ?>" alt="<?php echo esc_attr( get_the_title() ); ?>">
									<div class="red-overlay"></div><!-- end .red-overlay -->
								</a>
								<figcaption>
									<div class="popup-image">
										<a href="<?php echo esc_url( $img_array_large[0] ); ?>" data-lightbox="masonry"><i class="fa fa-eye"></i></a>
										<a href="<?php echo esc_url( get_permalink() ); ?>"><i class="fa fa-link"></i></a>
									</div><!-- end .popup-image -->

									<div class="portfolio-content">
										<div class="tag">
											<small>
												<?php
												$no_of_cat = 1;
			                                    foreach ( $post_categories as $post_category ) {
			                                        $category_id   = $post_category->term_id;
			                                        $category_name = $post_category->name;
			                                        $category_url  = get_category_link( $category_id );

			                                        echo ' <a href="' . esc_url( $category_url ) . '">'. esc_html( $category_name ) . '</a>';
			                                        if( $no_of_cat == 5 ) break;
			                                        $no_of_cat++;
			                                    } 
												?>
											</small>
										</div>
										<div class="portfolio-title">
											<a href="<?php echo esc_url( get_permalink() ); ?>"><h4><?php echo esc_html( get_the_title() ); ?></h4></a>
										</div><!-- end .portfolio-title -->

										<div class="portfolio-desc">
											<p class="desc"><?php echo esc_html( photo_fusion_pro_trim_content( $post, absint( $options['excerpt_length'] ) ) ); ?></p>
										</div><!-- end .portfolio-title -->
									</div><!-- end .portfolio-content -->
								</figcaption>
							</figure>
						</div><!-- end box -->
					<?php endif; $img_count++; $i++;
				endwhile;
			endif; 
			wp_reset_postdata();
	    die();
	}
endif;
add_action("wp_ajax_photo_fusion_pro_gallery_ajax_handler", "photo_fusion_pro_gallery_ajax_handler");
add_action("wp_ajax_nopriv_photo_fusion_pro_gallery_ajax_handler", "photo_fusion_pro_gallery_ajax_handler");