<?php
/**
 * Slider section
 *
 * This is the template for the content of slider section
 *
 * @package Theme Palace
 * @subpackage Photo Fusion Pro
 * @since Photo Fusion Pro 1.0
 */
if ( ! function_exists( 'photo_fusion_pro_add_slider_section' ) ) :
  /**
   * Add slider section
   *
   * @since Photo Fusion Pro 1.0
   */
  function photo_fusion_pro_add_slider_section() {

    // Check if slider is enabled on frontpage
    $slider_enable = apply_filters( 'photo_fusion_pro_section_status', true, 'slider_enable' );
    if ( true !== $slider_enable ) {
      return false;
    }

    // Get slider section details
    $section_details = array();
    $section_details = apply_filters( 'photo_fusion_pro_filter_slider_section_details', $section_details );

    if ( empty( $section_details ) ) {
      return;
    }

    // Render slider section now.
    photo_fusion_pro_render_slider_section( $section_details );
  }
endif;
add_action( 'photo_fusion_pro_primary_content', 'photo_fusion_pro_add_slider_section', 10 );


if ( ! function_exists( 'photo_fusion_pro_get_slider_section_details' ) ) :
  /**
   * Slider section details.
   *
   * @since  Photo Fusion Pro 1.0
   *
   * @param array $input Slider section details.
   */
  function photo_fusion_pro_get_slider_section_details( $input ) {
    $options = photo_fusion_pro_get_theme_options();

    // Slider type
    $slider_content_type  = $options['slider_content_type'];

    $content = array();
    switch ( $slider_content_type ) {
      case 'demo':
        for ( $i=1; $i<=3; $i++ ) {
          $content[ $i ]['img_array'][0] = get_template_directory_uri() . '/assets/uploads/slider-0'.$i.'.jpg';
          $content[$i]['author']         = esc_html__( 'Portrait', 'photo-fusion-pro' );
          $content[$i]['url']            = '#';
          $content[$i]['title']          = esc_html__( 'Fireworks', 'photo-fusion-pro' );
          $content[$i]['excerpt']        = esc_html__( 'Proin sit amet pellentesque odio curabitur placerat massa urna, sed volutpat lacus vehicula ac. Donec vitae cursus libero, nec blandit dolor.', 'photo-fusion-pro' );
          $content[$i]['alt']            = esc_html__( 'Slider Image', 'photo-fusion-pro' );
        }
      break;

      case 'page':
        $ids = array();

        for ( $i = 1; $i <= $options['slider_content_page_count']; $i++ ) {
            $id = null;
            if ( isset( $options[ 'slider_content_page_'.$i ] ) ) {
                $id = $options[ 'slider_content_page_'.$i ];
            }
            if ( ! empty( $id ) ) {
                $ids[] = absint( $id );
            }
        }

        // Bail if no valid pages are selected.
        if ( empty( $ids ) ) {
            return $input;
        }

        $args = array(
            'no_found_rows'  => true,
            'orderby'        => 'post__in',
            'post_type'      => 'page',
            'post__in'       => $ids,
        );
      break;

      case 'post':
        $ids = array();

        for ( $i = 1; $i <= $options['slider_content_page_count']; $i++ ) {
            $id = null;
            if ( isset( $options[ 'slider_content_post_'.$i ] ) ) {
                $id = $options[ 'slider_content_post_'.$i ];
            }
            if ( ! empty( $id ) ) {
                $ids[] = absint( $id );
            }
        }

        // Bail if no valid pages are selected.
        if ( empty( $ids ) ) {
            return $input;
        }

        $args = array(
            'no_found_rows'  => true,
            'orderby'        => 'post__in',
            'post_type'      => 'post',
            'post__in'       => $ids,
        );
      break;

      case 'category':
        $cat_id = '';
        if ( !empty( $options['slider_content_category'] ) ) {
            $cat_id = $options['slider_content_category'];
        }

        // Bail if no valid pages are selected.
        if ( empty( $cat_id ) ) {
            return $input;
        }else{
            $cat_id = absint( $cat_id );
        }

        $args = array(
            'no_found_rows'  => true,
            'cat'            => $cat_id,
            'post_type'      => 'post',
            'posts_per_page' => absint( $options['slider_content_page_count'] ),
            'orderby'        => 'ASC',
        );
      break;

      default:
      break;
    }

    if ( 'demo' != $slider_content_type ) {
      // Fetch posts.
      $posts = get_posts( $args );

      if ( ! empty( $posts ) ) {

          $i = 1;
          foreach ( $posts as $key => $post ) {
              $page_id = $post->ID;
              $img_array = null;
            if ( has_post_thumbnail( $page_id ) ) {
                $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $post->ID ), 'full' );
            } else {
                $img_array[0] =  get_template_directory_uri().'/assets/uploads/no-featured-image-1920x1080.png';
            }

            if ( isset( $img_array ) ) {
              $content[$i]['img_array'] = $img_array;
            }

            $content[$i]['author']   = get_the_author_meta('user_nicename', $post->post_author );
            $content[$i]['url']      = get_permalink( $page_id );
            $content[$i]['title']    = get_the_title( $page_id );
            $content[$i]['excerpt']  = photo_fusion_pro_trim_content( $post, 21 );
            $content[$i]['alt']      = get_the_title( $page_id );

            $i++;
          }
      }
    }

    if ( ! empty( $content ) ) {
      $input = $content;
    }
    return $input;
  }
endif;
// Slider section content details.
add_filter( 'photo_fusion_pro_filter_slider_section_details', 'photo_fusion_pro_get_slider_section_details' );


if ( ! function_exists( 'photo_fusion_pro_render_slider_section' ) ) :
  /**
   * Start section class .main-slider
   *
   * @return string Slider content
   * @since  Photo Fusion Pro 1.0
   *
   */
   function photo_fusion_pro_render_slider_section( $content_details = array() ) {
    $options = photo_fusion_pro_get_theme_options();
    $readmore = ! empty( $options['slider_button_text'] ) ? $options['slider_button_text'] : esc_html( 'View Details', 'photo-fusion-pro' );

    if ( empty( $content_details ) ) {
      return;
    }

    $i = 1; 
    ?>
    <section class="main-slider">
        <div class="cycle-slideshow" 
            data-cycle-timeout="2500" 
            data-cycle-pause-on-hover="true" 
            data-cycle-speed="800" 
            data-cycle-fx="<?php echo esc_attr( $options["slider_content_effect"] );?>" 
            data-cycle-slides=">figure" 
            data-cycle-next="#next" 
            data-cycle-prev="#prev" 
            data-cycle-pager=".cycle-pager">

            <?php foreach ( $content_details as $content ): ?>
            <figure style="background-image: url('<?php echo esc_url( $content['img_array'][0]); ?>');<?php echo ( $i == 1 ) ? 'display:block;' : 'display:none;'; ?>">
                <div class="black-overlay"></div><!-- end .black-overlay -->
                <?php if ( $options['enable_slider_captions'] ) { ?>
                <div class="slider-contents">
                    <div class="text-wrapper">
                        <div class="layer-1 os-animation" data-os-animation="slideInDown" data-os-animation-delay="0.1s" data-os-animation-duration="2s">
                            <h5><?php echo esc_html( $content['author'] ); ?></h5>
                        </div><!-- end .layer-1 --> 

                        <div class="layer-2 os-animation" data-os-animation="slideInLeft" data-os-animation-delay="0.1s" data-os-animation-duration="1s">
                            <a href="<?php echo esc_url( $content['url'] ); ?>">
                              <h1><?php echo esc_html( $content['title'] ); ?></h1>
                            </a>
                        </div><!-- end .layer-2 --> 

                        <?php if ( $options['enable_slider_excerpt'] ) : ?>
                            <div class="layer-3 os-animation" data-os-animation="slideInRight" data-os-animation-delay="0.1s" data-os-animation-duration="1s">
                                <h5><?php echo esc_html( $content['excerpt'] ); ?></h5>
                            </div><!-- end .layer-3 -->
                        <?php endif; ?>
                    </div><!-- end .text-wrapper -->

                    <div class="layer-4 os-animation" data-os-animation="zoomIn" data-os-animation-delay="0.1s" data-os-animation-duration="2s">
                      <a href="<?php echo esc_url( $content['url'] ); ?>" class="btn fill btn-js"><?php echo esc_html( $readmore ); ?></a>
                    </div><!-- end .layer-4 --> 
                </div><!-- end .slider-contents -->
                <?php } ?>
            </figure><!-- end first slide-->
            <?php $i++;
            endforeach; ?>

            <?php if ( $options['enable_arrow_controls'] || $options['enable_slider_pager'] ) { 

                $control_class = $options['enable_slider_control_at_bottom'] ? 'control-align-bottom' : 'control-align-right';
            ?>
            <div class="<?php echo esc_attr( $control_class ); ?>">

                <div class="controls">
                    <?php if ( $options['enable_arrow_controls'] ) : ?>
                        <div class="cycle-prev"><a href="#" id="prev"><i class="fa fa-angle-up"></i></a></div>
                    <?php endif; 
                    if ( $options['enable_slider_pager'] ) : ?>
                        <div class="cycle-pager"></div><!-- end .cycle-pager -->
                    <?php endif; ?>
                    <?php if ( $options['enable_arrow_controls'] ) : ?>
                        <div class="cycle-next"><a href="#" id="next"><i class="fa fa-angle-down"></i></a></div>
                    <?php endif; ?>
                </div><!--end .controls-->
            </div>
            <?php } ?>
        </div><!--end .cycle-slideshow-->
    </section><!--end .main-slider -->

<?php }
endif;